@@ -1,6 +1,6 @@
 package CHI;
 BEGIN {
-  $CHI::VERSION = '0.53';
+  $CHI::VERSION = '0.54';
 }
 use 5.006;
 use Carp;
@@ -180,7 +180,7 @@ CHI - Unified cache handling interface
 
 =head1 VERSION
 
-version 0.53
+version 0.54
 
 =head1 SYNOPSIS
 
@@ -342,11 +342,14 @@ An object to use for serializing keys that are references. See L</serializer>
 above for the different ways this can be passed in. The default is to use JSON
 in canonical mode (sorted hash keys).
 
+=for html <a name="label">
+
 =item label [STRING]
 
 A label for the cache as a whole, independent of namespace - e.g.
-"web-file-cache". Used when referring to the cache in logs, statistics, and
-error messages. By default, set to L</short_driver_name>.
+"web-file-cache". Used when referring to the cache in logs,
+L<statistics|CHI::Stats>, and error messages. By default, set to
+L</short_driver_name>.
 
 =item l1_cache [HASHREF]
 
@@ -790,6 +793,8 @@ cache.
 
 =head2 Property accessors
 
+=for html <a name="chi_root_class">
+
 =over
 
 =item chi_root_class( )
