@@ -1,6 +1,6 @@
 package CHI::Util;
 BEGIN {
-  $CHI::Util::VERSION = '0.53';
+  $CHI::Util::VERSION = '0.54';
 }
 use Carp qw( croak longmess );
 use Class::MOP;
@@ -8,6 +8,7 @@ use Data::Dumper;
 use Data::UUID;
 use Fcntl qw( :DEFAULT );
 use File::Spec::Functions qw(catdir catfile);
+use JSON;
 use Time::Duration::Parse;
 use Try::Tiny;
 use strict;
@@ -20,6 +21,8 @@ our @EXPORT_OK = qw(
   fast_catdir
   fast_catfile
   has_moose_class
+  json_decode
+  json_encode
   parse_duration
   parse_memory_size
   read_file
@@ -31,6 +34,11 @@ our @EXPORT_OK = qw(
 my $Fetch_Flags = O_RDONLY | O_BINARY;
 my $Store_Flags = O_WRONLY | O_CREAT | O_BINARY;
 
+# Map null, true and false to real Perl values
+if ( JSON->VERSION < 2 ) {
+    $JSON::UnMapping = 1;
+}
+
 sub can_load {
 
     # Load $class_name if possible. Return 1 if successful, 0 if it could not be
@@ -174,6 +182,23 @@ sub has_moose_class {
     return ( defined $meta && $meta->isa("Moose::Meta::Class") );
 }
 
+# Maintain compatibility with both JSON 1 and 2. Borrowed from Data::Serializer::JSON.
+#
+my $json_version = JSON->VERSION;
+my $json = $json_version < 2 ? JSON->new : JSON->new->utf8->canonical;
+
+sub json_decode {
+    return $json_version < 2
+      ? $json->jsonToObj( $_[0] )
+      : $json->decode( $_[0] );
+}
+
+sub json_encode {
+    return $json_version < 2
+      ? $json->objToJson( $_[0] )
+      : $json->encode( $_[0] );
+}
+
 1;
 
 __END__
