@@ -1,6 +1,6 @@
 package CHI::t::Driver;
 BEGIN {
-  $CHI::t::Driver::VERSION = '0.53';
+  $CHI::t::Driver::VERSION = '0.54';
 }
 use strict;
 use warnings;
@@ -587,7 +587,7 @@ sub test_serialize : Tests {
 {
     package DummySerializer;
 BEGIN {
-  $DummySerializer::VERSION = '0.53';
+  $DummySerializer::VERSION = '0.54';
 }
     sub serialize   { }
     sub deserialize { }
@@ -1244,6 +1244,9 @@ sub test_logging : Tests {
 sub test_stats : Tests {
     my $self = shift;
 
+    return 'author testing only - possible differences between JSON versions'
+      unless ( $ENV{AUTHOR_TESTING} );
+
     my $stats = $self->testing_chi_root_class->stats;
     $stats->enable();
 
@@ -1275,25 +1278,25 @@ sub test_stats : Tests {
     $log->empty_ok();
     $stats->flush();
     $log->contains_ok(
-        qr/CHI stats: namespace='Foo'; cache='$label'; start=.*; end=.*; absent_misses=2; expired_misses=1; get_time_ms=\d+; hits=1; set_key_size=6; set_time_ms=\d+; set_value_size=20; sets=1/
+        qr/CHI stats: {"absent_misses":2,"end_time":\d+,"expired_misses":1,"get_time_ms":\d+,"hits":1,"label":"$label","namespace":"Foo","root_class":"CHI","set_key_size":6,"set_time_ms":\d+,"set_value_size":20,"sets":1,"start_time":\d+}/
     );
     $log->contains_ok(
-        qr/CHI stats: namespace='Bar'; cache='$label'; start=.*; end=.*; set_key_size=12; set_time_ms=\d+; set_value_size=52; sets=2/
+        qr/CHI stats: {"end_time":\d+,"label":"$label","namespace":"Bar","root_class":"CHI","set_key_size":12,"set_time_ms":\d+,"set_value_size":52,"sets":2,"start_time":\d+}/
     );
     $log->contains_ok(
-        qr/CHI stats: namespace='Baz'; cache='$label'; start=.*; end=.*; absent_misses=1; compute_time_ms=\d\d+; computes=1; get_time_ms=\d+; hits=2; set_key_size=6; set_time_ms=\d+; set_value_size=44; sets=1/
+        qr/CHI stats: {"absent_misses":1,"compute_time_ms":\d+,"computes":1,"end_time":\d+,"get_time_ms":\d+,"hits":2,"label":"$label","namespace":"Baz","root_class":"CHI","set_key_size":6,"set_time_ms":\d+,"set_value_size":44,"sets":1,"start_time":\d+}/
     );
     $log->empty_ok();
 
     my @logs = (
-        "CHI stats: namespace='Foo'; cache='File'; start=20090102:12:53:05; end=20090102:12:58:05; hits=3; sets=5",
-        "CHI stats: namespace='Foo'; cache='File'; start=20090102:12:53:05; end=20090102:12:58:05; hits=1; sets=7",
-        "CHI stats: namespace='Bar'; cache='File'; start=20090102:12:53:05; end=20090102:12:58:05; hits=4; sets=9",
-        "CHI stats: namespace='Foo'; cache='File'; start=20090102:12:53:05; end=20090102:12:58:05; sets=3",
-        "CHI stats: namespace='Foo'; cache='File'; start=20090102:12:53:05; end=20090102:12:58:05; hits=8",
-        "CHI stats: namespace='Foo'; cache='Memory'; start=20090102:12:53:05; end=20090102:12:58:05; sets=2",
-        "CHI stats: namespace='Bar'; cache='File'; start=20090102:12:53:05; end=20090102:12:58:05; hits=10; sets=1",
-        "CHI stats: namespace='Bar'; cache='File'; start=20090102:12:53:05; end=20090102:12:58:05; hits=3; set_errors=2",
+        'CHI stats: {"root_class":"CHI","namespace":"Foo","label":"File","start_time":1338404896,"end_time":1338404899,"hits":3,"sets":5}',
+        'CHI stats: {"root_class":"CHI","namespace":"Foo","label":"File","start_time":1338404896,"end_time":1338404899,"hits":1,"sets":7}',
+        'CHI stats: {"root_class":"CHI","namespace":"Bar","label":"File","start_time":1338404896,"end_time":1338404899,"hits":4,"sets":9}',
+        'CHI stats: {"root_class":"CHI","namespace":"Foo","label":"File","start_time":1338404896,"end_time":1338404899,"sets":3}',
+        'CHI stats: {"root_class":"CHI","namespace":"Foo","label":"File","start_time":1338404896,"end_time":1338404899,"hits":8}',
+        'CHI stats: {"root_class":"CHI","namespace":"Foo","label":"Memory","start_time":1338404896,"end_time":1338404899,"sets":2}',
+        'CHI stats: {"root_class":"CHI","namespace":"Bar","label":"File","start_time":1338404896,"end_time":1338404899,"hits":10,"sets":1}',
+        'CHI stats: {"root_class":"CHI","namespace":"Bar","label":"File","start_time":1338404896,"end_time":1338404899,"hits":3,"set_errors":2}',
     );
     my $log_dir = tempdir( "chi-test-stats-XXXX", TMPDIR => 1, CLEANUP => 1 );
     write_file( "$log_dir/log1", join( "\n", splice( @logs, 0, 4 ) ) . "\n" );
@@ -1307,14 +1310,14 @@ sub test_stats : Tests {
             {
                 root_class => 'CHI',
                 namespace  => 'Foo',
-                cache      => 'File',
+                label      => 'File',
                 hits       => 12,
                 sets       => 15
             },
             {
                 root_class => 'CHI',
                 namespace  => 'Bar',
-                cache      => 'File',
+                label      => 'File',
                 hits       => 17,
                 sets       => 10,
                 set_errors => 2
@@ -1322,7 +1325,7 @@ sub test_stats : Tests {
             {
                 root_class => 'CHI',
                 namespace  => 'Foo',
-                cache      => 'Memory',
+                label      => 'Memory',
                 sets       => 2
             }
         ],
